==> eam-wshub-proxyclient-11.4-8-sources.jar: net/datastream/schemas/mp_fields/ASSEMBLYLEVELID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour ASSEMBLYLEVELID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="ASSEMBLYLEVELID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ASSEMBLYLEVELCODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DESCRIPTION" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ASSEMBLYLEVELID_Type", propOrder = {
    "assemblylevelcode",
    "description"
})
public class ASSEMBLYLEVELID_Type {

    @XmlElement(name = "ASSEMBLYLEVELCODE", required = true)
    protected String assemblylevelcode;
    @XmlElement(name = "DESCRIPTION")
    protected String description;

    /**
     * Obtient la valeur de la propriété assemblylevelcode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getASSEMBLYLEVELCODE() {
        return assemblylevelcode;
    }

    /**
     * Définit la valeur de la propriété assemblylevelcode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setASSEMBLYLEVELCODE(String value) {
        this.assemblylevelcode = value;
    }

    /**
     * Obtient la valeur de la propriété description.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDESCRIPTION() {
        return description;
    }

    /**
     * Définit la valeur de la propriété description.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDESCRIPTION(String value) {
        this.description = value;
    }

}

==> eam-wshub-proxyclient-12.0-sources.jar: net/datastream/schemas/mp_fields/ASSEMBLYLEVELID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for ASSEMBLYLEVELID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="ASSEMBLYLEVELID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ASSEMBLYLEVELCODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DESCRIPTION" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ASSEMBLYLEVELID_Type", propOrder = {
    "assemblylevelcode",
    "description"
})
public class ASSEMBLYLEVELID_Type {

    @XmlElement(name = "ASSEMBLYLEVELCODE", required = true)
    protected String assemblylevelcode;
    @XmlElement(name = "DESCRIPTION")
    protected String description;

    /**
     * Gets the value of the assemblylevelcode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getASSEMBLYLEVELCODE() {
        return assemblylevelcode;
    }

    /**
     * Sets the value of the assemblylevelcode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setASSEMBLYLEVELCODE(String value) {
        this.assemblylevelcode = value;
    }

    /**
     * Gets the value of the description property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDESCRIPTION() {
        return description;
    }

    /**
     * Sets the value of the description property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDESCRIPTION(String value) {
        this.description = value;
    }

}
